package com.ruoyi.szxc.service;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcDiscussCentre;

/**
 * 议事中心Service接口
 * 
 * @author hs
 * @date 2024-03-20
 */
public interface ISzxcDiscussCentreService 
{
    /**
     * 查询议事中心
     * 
     * @param id 议事中心主键
     * @return 议事中心
     */
    public SzxcDiscussCentre selectSzxcDiscussCentreById(Long id);

    /**
     * 查询议事中心列表
     * 
     * @param szxcDiscussCentre 议事中心
     * @return 议事中心集合
     */
    public List<SzxcDiscussCentre> selectSzxcDiscussCentreList(SzxcDiscussCentre szxcDiscussCentre);

    /**
     * 新增议事中心
     * 
     * @param szxcDiscussCentre 议事中心
     * @return 结果
     */
    public int insertSzxcDiscussCentre(SzxcDiscussCentre szxcDiscussCentre);

    /**
     * 修改议事中心
     * 
     * @param szxcDiscussCentre 议事中心
     * @return 结果
     */
    public int updateSzxcDiscussCentre(SzxcDiscussCentre szxcDiscussCentre);

    /**
     * 批量删除议事中心
     * 
     * @param ids 需要删除的议事中心主键集合
     * @return 结果
     */
    public int deleteSzxcDiscussCentreByIds(Long[] ids);

    /**
     * 删除议事中心信息
     * 
     * @param id 议事中心主键
     * @return 结果
     */
    public int deleteSzxcDiscussCentreById(Long id);
}
